@@ -1,14 +1,16 @@
 package ShellCompleter::Util;
 
-our $DATE = '2019-08-17'; # DATE
-our $VERSION = '0.031'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
 
-require Exporter;
-our @ISA = qw(Exporter);
+use Exporter qw(import);
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2024-07-09'; # DATE
+our $DIST = 'ShellCompleter-Util'; # DIST
+our $VERSION = '0.032'; # VERSION
+
 our @EXPORT_OK = qw(
                     run_shell_completer_for_getopt_long_app
                );
@@ -28,12 +30,11 @@ sub _complete {
         return Complete::Util::complete_array_elem(
             array => $comp,
             word  => $args->{word},
-            ci    => $args->{ci},
         );
     } elsif (ref($comp) eq 'CODE') {
         return $comp->(%$args);
     } else {
-        return undef;
+        return;
     }
 }
 
@@ -80,7 +81,7 @@ ShellCompleter::Util - Utility routines for App::ShellCompleter::*
 
 =head1 VERSION
 
-This document describes version 0.031 of ShellCompleter::Util (from Perl distribution ShellCompleter-Util), released on 2019-08-17.
+This document describes version 0.032 of ShellCompleter::Util (from Perl distribution ShellCompleter-Util), released on 2024-07-09.
 
 =head1 SYNOPSIS
 
@@ -103,14 +104,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/ShellCompl
 
 Source repository is at L<https://github.com/perlancar/perl-ShellCompleter-Util>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=ShellCompleter-Util>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 C<App::ShellCompleter::*> modules which use this module, e.g.
@@ -122,11 +115,37 @@ L<Getopt::Long::Complete>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018, 2016, 2015 by perlancar@cpan.org.
+This software is copyright (c) 2024, 2018, 2016, 2015 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=ShellCompleter-Util>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
